/****************************************************************************
 * Copyright (c) 2010-2012, EBM WebSourcing - All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/
 
package org.ow2.petals.commons.log;

import java.util.ArrayList;
import java.util.List;

/**
 * Class allowing to define specific <Level> to Petals in addition to JDK
 * logging levels.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public final class Level extends java.util.logging.Level {

    private static final long serialVersionUID = 7069488588928445758L;

    /**
     * Logging Level to trace steps of a service orchestration
     */
    public static final java.util.logging.Level MONIT = new Level("MONIT", 600);

    /**
     * Name of supported logging levels.
     */
    public final static List<java.util.logging.Level> SUPPORTED_LEVELS = new ArrayList<java.util.logging.Level>();

    static {
        Level.SUPPORTED_LEVELS.add(OFF);
        Level.SUPPORTED_LEVELS.add(SEVERE);
        Level.SUPPORTED_LEVELS.add(WARNING);
        Level.SUPPORTED_LEVELS.add(INFO);
        Level.SUPPORTED_LEVELS.add(CONFIG);
        Level.SUPPORTED_LEVELS.add(MONIT);
        Level.SUPPORTED_LEVELS.add(FINE);
        Level.SUPPORTED_LEVELS.add(FINER);
        Level.SUPPORTED_LEVELS.add(FINEST);
        Level.SUPPORTED_LEVELS.add(ALL);
    }

    protected Level(String name, int value) {
        super(name, value);
    }

    /**
     * This empty method must be called before any use of a custom Level. Custom
     * Level constructor add custom Levels to known Levels registered in
     * {@link java.util.logging.Level} class.
     */
    public static void initialize() {
        // NOP
    }
}