/****************************************************************************
 * Copyright (c) 2010-2012, EBM WebSourcing - All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/
 
package org.ow2.petals.commons.log;

import static org.junit.Assert.assertSame;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

public class LevelTest {

    @Test
    public final void testGettingDefaultLevelsReturnJDKObjects() throws Exception {
        assertSame(java.util.logging.Level.OFF, Level.OFF);
        assertSame(java.util.logging.Level.SEVERE, Level.SEVERE);
        assertSame(java.util.logging.Level.WARNING, Level.WARNING);
        assertSame(java.util.logging.Level.INFO, Level.INFO);
        assertSame(java.util.logging.Level.CONFIG, Level.CONFIG);
        assertSame(java.util.logging.Level.FINE, Level.FINE);
        assertSame(java.util.logging.Level.FINER, Level.FINER);
        assertSame(java.util.logging.Level.FINEST, Level.FINEST);
        assertSame(java.util.logging.Level.ALL, Level.ALL);
    }

    @Test
    public final void testMONITLevelBetweenCONFIGandFINE() throws Exception {
        assertTrue(Level.CONFIG.intValue() > Level.MONIT.intValue());
        assertTrue(Level.MONIT.intValue() > Level.FINE.intValue());
    }

    @Test
    public final void testGettingMONITLevelSeveralTimesReturnSameObject() throws Exception {
        assertSame(Level.MONIT, Level.MONIT);
    }

    @Test
    public final void testParsingDefaultLevelsReturnJDKObjects() throws Exception {
        assertSame(java.util.logging.Level.OFF, Level.parse("OFF"));
        assertSame(java.util.logging.Level.SEVERE, Level.parse("SEVERE"));
        assertSame(java.util.logging.Level.WARNING, Level.parse("WARNING"));
        assertSame(java.util.logging.Level.INFO, Level.parse("INFO"));
        assertSame(java.util.logging.Level.CONFIG, Level.parse("CONFIG"));
        assertSame(java.util.logging.Level.FINE, Level.parse("FINE"));
        assertSame(java.util.logging.Level.FINER, Level.parse("FINER"));
        assertSame(java.util.logging.Level.FINEST, Level.parse("FINEST"));
        assertSame(java.util.logging.Level.ALL, Level.parse("ALL"));
    }
    
    @Test
    public final void testParsingMONITLevel() throws Exception {
        assertSame(Level.MONIT, Level.parse("MONIT"));
    }

    @Test
    public final void testJdkParsingMONITLevel() throws Exception {
        assertSame(Level.MONIT, java.util.logging.Level.parse("MONIT"));
    }
}
