/****************************************************************************
 * Copyright (c) 2010-2012, EBM WebSourcing - All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/
 
package org.ow2.petals.commons.log;

import java.util.AbstractMap;
import java.util.Collection;
import java.util.HashMap;
import java.util.Set;
import java.util.Map.Entry;

import org.junit.Test;

import static org.junit.Assert.*;

public class LogDataTest {

    @Test
    public void testPutData() {
        LogData logData = new TestLogData();
        logData.putData("testKey", "testValue");
        assertEquals("testValue",logData.get("testKey"));
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testKeySetUnmodifiable() {
        LogData logData = new TestLogData();
        Set<String> keySet = logData.keySet();
        keySet.remove("test");
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testEntrySetUnmodifiable() {
        LogData logData = new TestLogData();
        logData.putData("test", "testKey");
        Set<Entry<String, Object>> entrySet = logData.entrySet();
        entrySet.remove(new AbstractMap.SimpleEntry<String, Object>("testKey", "testValue"));
    }

    @Test(expected = UnsupportedOperationException.class)
    public void testValuesUnmodifiable() {
        LogData logData = new TestLogData();
        Collection<Object> values = logData.values();
        values.remove(new Object());
    }

    @Test(expected = UnsupportedOperationException.class)
    public void testPutUnsupported() {
        LogData logData = new TestLogData();
        logData.put("test", "testKey");
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testPutAllUnsupported() {
        LogData logData = new TestLogData();
        HashMap<String, Object> map = new HashMap<String, Object>();
        map.put("test", "testKey");
        logData.putAll(map);
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testCloneUnsupported() {
        LogData logData = new TestLogData();
        logData.putData("test", "testKey");
        logData.clone();
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testClearUnsupported() {
        LogData logData = new TestLogData();
        logData.putData("test", "testKey");
        logData.clear();
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testRemoveUnsupported() {
        LogData logData = new TestLogData();
        logData.putData("test", "testKey");
        logData.remove("test");
    }
}
