/****************************************************************************
 * Copyright (c) 2010-2012, EBM WebSourcing - All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/
 
package org.ow2.petals.commons.log;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertSame;
import static org.junit.Assert.assertTrue;

import java.util.logging.ConsoleHandler;
import java.util.logging.FileHandler;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.junit.Test;

/**
 * @author aruffie
 * 
 */
public class LoggerHelperTest {

    @Test
    public void testGetLevelOrParentLevelOnChildOfRootLogger() {
        final Logger logger = Logger.getLogger("myChildLogger0");
        assertNotNull(LoggerHelper.getLevelOrParentLevel(logger));
    }

    @Test
    public void testGetLevelOrParentLevelOnChildOfUserLogger() {
        final Logger parentLogger = Logger.getLogger("myParentLogger1");
        parentLogger.setLevel(Level.FINEST);
        final Logger childLogger = Logger.getLogger("myParentLogger1.myChildLogger1");
        assertSame(parentLogger.getLevel(), LoggerHelper.getLevelOrParentLevel(childLogger));
    }

    @Test
    public void testGetLevelOrParentLevelOnLittleChildUserLogger() {
        final Logger parentLogger = Logger.getLogger("myParentLogger2");
        parentLogger.setLevel(Level.FINEST);
        final Logger littleChildLogger = Logger
                .getLogger("myParentLogger2.myChildLogger2.myLittleChildLogger2");
        assertSame(parentLogger.getLevel(), LoggerHelper.getLevelOrParentLevel(littleChildLogger));
    }

    @Test
    public void testGetLevelOrParentLevelOnChildOfUserLoggerWhenSpecificLevelGiven() {
        final Logger parentLogger = Logger.getLogger("myParentLogger3");
        final Logger childLogger = Logger.getLogger("myParentLogger3.myChild3");
        childLogger.setLevel(Level.SEVERE);
        parentLogger.setLevel(Level.INFO);
        assertEquals(Level.SEVERE, LoggerHelper.getLevelOrParentLevel(childLogger));
    }
    
    @Test
    public void testGetHandlersOrParentHanderslOnChildOfRootLogger() {
        final Logger rootLogger = Logger.getLogger("");
        final ConsoleHandler parentHandler = new ConsoleHandler();
        rootLogger.addHandler(parentHandler);
        final Logger logger = Logger.getLogger("myChildLogger0");
        assertTrue(LoggerHelper.getHandlersOrParentHanders(logger).contains(parentHandler));
    }
    
    @Test
    public void testGetHandlersOrParentHanderslOnALogger() {
        final Logger logger = Logger.getLogger("myChildLogger0");
        final ConsoleHandler parentHandler = new ConsoleHandler();
        logger.addHandler(parentHandler);
        assertTrue(LoggerHelper.getHandlersOrParentHanders(logger).contains(parentHandler));
    }
    
    @Test
    public void testGetHandlersOrParentHandersOnLittleChildUserLoggerWithUseParentHandlersToTrue() {
        final Logger parentLogger = Logger.getLogger("myParentLogger2");
        final ConsoleHandler parentHandler = new ConsoleHandler();
        parentLogger.addHandler(parentHandler);
        final Logger littleChildLogger = Logger
                .getLogger("myParentLogger2.myChildLogger2.myLittleChildLogger2");
        assertTrue(LoggerHelper.getHandlersOrParentHanders(littleChildLogger).contains(parentHandler));
    }
    
    @Test
    public void testGetHandlersOrParentHandersOnLittleChildUserLoggerWithUseParentHandlersToFalseAndNoHandlerOnChildLogger() {
        final Logger parentLogger = Logger.getLogger("myParentLogger2");
        final ConsoleHandler parentHandler = new ConsoleHandler();
        parentLogger.addHandler(parentHandler);
        final Logger childLogger = Logger
                .getLogger("myParentLogger2.myChildLogger2");
        childLogger.setUseParentHandlers(false);
        final Logger littleChildLogger = Logger
                .getLogger("myParentLogger2.myChildLogger2.myLittleChildLogger2");
        assertTrue(!LoggerHelper.getHandlersOrParentHanders(littleChildLogger).contains(parentHandler));
    }
    
    @Test
    public void testGetHandlersOrParentHandersOnLittleChildUserLoggerWithUseParentHandlersToFalseAndAHandlerOnChildLogger() throws Exception {
        final Logger parentLogger = Logger.getLogger("myParentLogger2");
        final ConsoleHandler parentHandler = new ConsoleHandler();
        parentLogger.addHandler(parentHandler);
        final Logger childLogger = Logger
                .getLogger("myParentLogger2.myChildLogger2");
        childLogger.setUseParentHandlers(false);
        final FileHandler childHandler = new FileHandler();
        childLogger.addHandler(childHandler);
        final Logger littleChildLogger = Logger
                .getLogger("myParentLogger2.myChildLogger2.myLittleChildLogger2");
        assertTrue(LoggerHelper.getHandlersOrParentHanders(littleChildLogger).contains(childHandler));
    }
}
