/****************************************************************************
 *
 * Copyright (c) 2011-2012, EBM WebSourcing
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
 *
 *****************************************************************************/
 
package org.ow2.petals.commons.log;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNotSame;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import java.util.Properties;

import javax.xml.namespace.QName;

import org.junit.After;
import org.junit.Test;

import com.ebmwebsourcing.easycommons.properties.PropertiesHelper;
import com.ebmwebsourcing.easycommons.thread.ExecutionContext;

/**
 * @author Mathieu Carrolle - EBM WebSourcing
 */
public class PetalsExecutionContextTest {

    @After
    public void after() {
        ExecutionContext.getProperties().clear();
    }

    @Test
    public void testPutFlowInstanceId() throws Exception {
        final String flowInstanceId = "flowInstanceId";
        PetalsExecutionContext.putFlowInstanceId(flowInstanceId);
        Properties expectedProperties = new Properties();
        expectedProperties.setProperty(PetalsExecutionContext.FLOW_INSTANCE_ID_PROPERTY_NAME,
                flowInstanceId);
        assertEquals(expectedProperties,
                PropertiesHelper.flattenProperties(ExecutionContext.getProperties()));
    }

    @Test
    public void testInitFlowInstanceId() throws Exception {
        PetalsExecutionContext.initFlowInstanceId();
        Properties contextualProperties = PropertiesHelper.flattenProperties(ExecutionContext.getProperties());
        String flowInstanceId = contextualProperties
                .getProperty(PetalsExecutionContext.FLOW_INSTANCE_ID_PROPERTY_NAME);
        assertNotNull(flowInstanceId);
        assertTrue(!flowInstanceId.isEmpty());
    }
    
    @Test
    public void testPutFlowStepId() throws Exception {
        final String flowStepId = "flowStepId";
        PetalsExecutionContext.putFlowStepId(flowStepId);
        Properties expectedProperties = new Properties();
        expectedProperties.setProperty(PetalsExecutionContext.FLOW_STEP_ID_PROPERTY_NAME,
                flowStepId);
        assertEquals(expectedProperties,
                PropertiesHelper.flattenProperties(ExecutionContext.getProperties()));
    }

    @Test
    public void testInitStepInstanceId() throws Exception {
        PetalsExecutionContext.nextFlowStepId();
        Properties contextualProperties = PropertiesHelper.flattenProperties(ExecutionContext.getProperties());
        String flowStepId = contextualProperties
                .getProperty(PetalsExecutionContext.FLOW_STEP_ID_PROPERTY_NAME);
        assertNotNull(flowStepId);
        assertTrue(!flowStepId.isEmpty());
    }

    @Test
    public void testNextFlowStepId() {
        final String flowStepId = "flowStepId1";
        PetalsExecutionContext.putFlowStepId(flowStepId);
        PetalsExecutionContext.nextFlowStepId();
        assertEquals(
                ExecutionContext.getProperties().get(
                        PetalsExecutionContext.FLOW_PREVIOUS_STEP_ID_PROPERTY_NAME), flowStepId);
        assertNotSame(
                ExecutionContext.getProperties().get(
                        PetalsExecutionContext.FLOW_STEP_ID_PROPERTY_NAME), flowStepId);
    }

    @Test
    public void testPutFlowStepInterfaceName() throws Exception {
        final QName interfaceName = new QName("http://org.ow2.petals.test/",
                "flowStepInterfaceName1");
        PetalsExecutionContext.putFlowStepInterfaceName(interfaceName);
        Properties expectedProperties = new Properties();
        expectedProperties.setProperty(
                PetalsExecutionContext.FLOW_STEP_INTERFACE_NAME_PROPERTY_NAME,
                interfaceName.toString());
        assertEquals(expectedProperties,
                PropertiesHelper.flattenProperties(ExecutionContext.getProperties()));
    }

    @Test
    public void testPutFlowStepOperationName() throws Exception {
        final QName operationName = new QName("http://org.ow2.petals.test/",
                "flowStepOperationName1");
        PetalsExecutionContext.putFlowStepOperationName(operationName);
        Properties expectedProperties = new Properties();
        expectedProperties.setProperty(
                PetalsExecutionContext.FLOW_STEP_OPERATION_NAME_PROPERTY_NAME,
                operationName.toString());
        assertEquals(expectedProperties,
                PropertiesHelper.flattenProperties(ExecutionContext.getProperties()));
    }

    @Test
    public void testPutFlowStepServiceName() throws Exception {
        final QName serviceName = new QName("http://org.ow2.petals.test/", "flowStepServiceName1");
        PetalsExecutionContext.putFlowStepServiceName(serviceName);
        Properties expectedProperties = new Properties();
        expectedProperties.setProperty(PetalsExecutionContext.FLOW_STEP_SERVICE_NAME_PROPERTY_NAME,
                serviceName.toString());
        assertEquals(expectedProperties,
                PropertiesHelper.flattenProperties(ExecutionContext.getProperties()));
    }

    @Test
    public void testPutFlowStepEndpointName() throws Exception {
        final String endpointName = "flowStepEndpointName1";
        PetalsExecutionContext.putFlowStepEndpointName(endpointName);
        Properties expectedProperties = new Properties();
        expectedProperties.setProperty(
                PetalsExecutionContext.FLOW_STEP_ENDPOINT_NAME_PROPERTY_NAME, endpointName);
        assertEquals(expectedProperties,
                PropertiesHelper.flattenProperties(ExecutionContext.getProperties()));
    }

    @Test
    public void testGetFlowAttributesButNoneInContext() throws Exception {
        assertNull(PetalsExecutionContext.getFlowAttributes());
    }

    @Test
    public void testGetFlowAttributesButFlowInstanceIdMissingInContext() throws Exception {
        ExecutionContext.getProperties().setProperty(
                PetalsExecutionContext.FLOW_STEP_ID_PROPERTY_NAME, "flowStepId1");
        assertNull(PetalsExecutionContext.getFlowAttributes());
    }

    @Test
    public void testGetFlowAttributesButFlowStepIdMissingInContext() throws Exception {
        ExecutionContext.getProperties().setProperty(
                PetalsExecutionContext.FLOW_INSTANCE_ID_PROPERTY_NAME, "flowInstanceId1");
        assertNull(PetalsExecutionContext.getFlowAttributes());
    }

    @Test
    public void testGetFlowAttributes() throws Exception {
        final String flowInstanceId = "flowInstanceId1";
        final String flowStepId = "flowStepId1";
        ExecutionContext.getProperties().setProperty(
                PetalsExecutionContext.FLOW_INSTANCE_ID_PROPERTY_NAME, flowInstanceId);
        ExecutionContext.getProperties().setProperty(
                PetalsExecutionContext.FLOW_STEP_ID_PROPERTY_NAME, flowStepId);
        FlowAttributes expectedFlowAttributes = new FlowAttributes(flowInstanceId, flowStepId);
        assertEquals(expectedFlowAttributes, PetalsExecutionContext.getFlowAttributes());
    }

    @Test
    public void testPutFlowAttributes() throws Exception {
        final String flowInstanceId = "flowInstanceId1";
        final String flowStepId = "flowStepId1";
        FlowAttributes flowAttributes = new FlowAttributes(flowInstanceId, flowStepId);

        PetalsExecutionContext.putFlowAttributes(flowAttributes);
        assertEquals(
                flowInstanceId,
                ExecutionContext.getProperties().getProperty(
                        PetalsExecutionContext.FLOW_INSTANCE_ID_PROPERTY_NAME));
        assertEquals(
                flowStepId,
                ExecutionContext.getProperties().getProperty(
                        PetalsExecutionContext.FLOW_STEP_ID_PROPERTY_NAME));

    }
}
